@@ -1,12 +1,15 @@
 package Perl::Examples::Module::One;
 
-our $DATE = '2020-03-07'; # DATE
-our $VERSION = '0.095'; # VERSION
-
 use strict;
 use warnings;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-02-24'; # DATE
+our $DIST = 'Perl-Examples'; # DIST
+our $VERSION = '0.096'; # VERSION
+
 our @EXPORT_OK = qw(fisbus);
 
 sub fisbus {
@@ -35,7 +38,7 @@ Perl::Examples::Module::One - Example module one
 
 =head1 VERSION
 
-This document describes version 0.095 of Perl::Examples::Module::One (from Perl distribution Perl-Examples), released on 2020-03-07.
+This document describes version 0.096 of Perl::Examples::Module::One (from Perl distribution Perl-Examples), released on 2023-02-24.
 
 =head1 SYNOPSIS
 
@@ -82,6 +85,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perl-Examp
 
 Source repository is at L<https://github.com/perlancar/perl-Perl-Examples>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2020, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Examples>
@@ -90,15 +122,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2018, 2016, 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
